==> linpsk_0.8.1.orig.tar.gz: linpsk-0.8.1/src/viterbi.h <==
/***************************************************************************
                          viterbi.h  -  description
                             -------------------
    begin                : Sam Mr 8 2003
    copyright            : (C) 2003 by Volker Schroer
    email                : dl1ksv@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef VITERBI_H
#define VITERBI_H


/**
  *@author Volker Schroer
  */

class Viterbi {
public: 
	Viterbi(int,unsigned int,unsigned int,const double (*)(double,int));
	~Viterbi();
  int encode(int);
//  void decode(int,const double (*)(int,int));
  void decode(double);

  int getbit(unsigned int i);
  int getbitinvers(unsigned int i);

private:
unsigned *StateTable;
long long int *PathMem;
double *Metric;
double * distance;
long long int * bitestimate;
int NumberofStates;
int MinimumPath;
unsigned int CoderState;
const double (*dist)(double,int);


};

#endif

==> linpsk_1.2.orig.tar.gz: linpsk-1.2/src/viterbi.h <==
/***************************************************************************
                          viterbi.h  -  description
                             -------------------
    begin                : Sam Mr 8 2003
    copyright            : (C) 2003 by Volker Schroer
    email                : dl1ksv@gmx.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef VITERBI_H
#define VITERBI_H


/**
  *@author Volker Schroer
  */

class Viterbi {
public: 
	Viterbi(int,unsigned int,unsigned int,const double (*)(double *,int));
	~Viterbi();
  int encode(int);
  void decode(double *);

  int getbit(unsigned int i);
  int getbitinvers(unsigned int i);

private:
unsigned *StateTable;
long long int *PathMem;
double *Metric;
double * distance;
long long int * bitestimate;
int NumberofStates;
int MinimumPath;
unsigned int CoderState;
const double (*dist)(double *,int);


};

#endif
